"""Constants."""
GOOD_HTTP_CODES = [200, 201, 202, 203]
FALSE_TEMPS = ["-400", "400"]

# common parameters
COOK_START = "acs"
TARGET_FOOD_TEMP = "tft"
TARGET_PIT_TEMP = "tpt"
GRILL_START = "ag"

# sending parameters
FOOD_PROBE = "p"
CURRENT_TIME = "ct"
COOK_END_TIME = "sce"
COOK_ID = "csid"
GRILL_END_TIME = "sge"
UNKOWN_VAR = "as"


# receiving parameters
PROBE_PIT = "pt"
PROBE_1 = "t1"
PROBE_2 = "t2"
PROBE_3 = "t3"
FAN_SPEED = "dc"
